@@ -1,6 +1,6 @@
 /*
-  Copyright(C) 2010-2018  Brazil
-  Copyright(C) 2019-2023  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2010-2018  Brazil
+  Copyright (C) 2019-2023  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -211,7 +211,7 @@ grn_inspect_type(grn_ctx *ctx, grn_obj *buf, unsigned char type)
 grn_obj *
 grn_inspect_query_log_flags(grn_ctx *ctx, grn_obj *buffer, unsigned int flags)
 {
-  grn_bool have_content = GRN_FALSE;
+  bool have_content = false;
 
   if (flags == GRN_QUERY_LOG_NONE) {
     GRN_TEXT_PUTS(ctx, buffer, "NONE");
@@ -225,9 +225,9 @@ grn_inspect_query_log_flags(grn_ctx *ctx, grn_obj *buffer, unsigned int flags)
         GRN_TEXT_PUTS(ctx, buffer, "|");                                       \
       }                                                                        \
       GRN_TEXT_PUTS(ctx, buffer, #NAME);                                       \
-      have_content = GRN_TRUE;                                                 \
+      have_content = true;                                                     \
     }                                                                          \
-  } while (GRN_FALSE)
+  } while (false)
 
   CHECK_FLAG(COMMAND);
   CHECK_FLAG(RESULT_CODE);
@@ -572,6 +572,8 @@ grn_store_inspect_body(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
   if (flags & GRN_OBJ_WITH_WEIGHT) {
     if (flags & GRN_OBJ_WEIGHT_FLOAT32) {
       GRN_TEXT_PUTS(ctx, buf, " weight:float32");
+    } else if (flags & GRN_OBJ_WEIGHT_BFLOAT16) {
+      GRN_TEXT_PUTS(ctx, buf, " weight:bfloat16");
     } else {
       GRN_TEXT_PUTS(ctx, buf, " weight:uint32");
     }
@@ -605,6 +607,18 @@ grn_store_inspect_body(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
     }
   }
 
+  if (flags & GRN_OBJ_COMPRESS_FILTER_SHUFFLE) {
+    GRN_TEXT_PUTS(ctx, buf, " compress-filter:shuffle");
+  }
+  if (flags & GRN_OBJ_COMPRESS_FILTER_BYTE_DELTA) {
+    GRN_TEXT_PUTS(ctx, buf, " compress-filter:byte-delta");
+  }
+  if (flags & GRN_OBJ_COMPRESS_FILTER_TRUNCATE_PRECISION_2BYTES) {
+    GRN_TEXT_PUTS(ctx, buf, " compress-filter:truncate-precision-2bytes");
+  } else if (flags & GRN_OBJ_COMPRESS_FILTER_TRUNCATE_PRECISION_1BYTE) {
+    GRN_TEXT_PUTS(ctx, buf, " compress-filter:truncate-precision-1byte");
+  }
+
   if (flags & GRN_OBJ_RING_BUFFER) {
     GRN_TEXT_PUTS(ctx, buf, " ring_buffer:true");
   }
@@ -715,6 +729,13 @@ grn_ii_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
     GRN_TEXT_PUTS(ctx, buf, "WEIGHT_FLOAT32");
     have_flags = true;
   }
+  if (flags & GRN_OBJ_WEIGHT_BFLOAT16) {
+    if (have_flags) {
+      GRN_TEXT_PUTS(ctx, buf, "|");
+    }
+    GRN_TEXT_PUTS(ctx, buf, "WEIGHT_BFLOAT16");
+    have_flags = true;
+  }
   if (!have_flags) {
     GRN_TEXT_PUTS(ctx, buf, "NONE");
   }
@@ -1239,7 +1260,7 @@ static grn_rc
 grn_record_inspect_common(grn_ctx *ctx,
                           grn_obj *buf,
                           grn_obj *obj,
-                          grn_bool with_columns)
+                          bool with_columns)
 {
   grn_obj *table;
 
@@ -1330,20 +1351,20 @@ grn_record_inspect_common(grn_ctx *ctx,
 grn_rc
 grn_record_inspect_without_columns(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
 {
-  return grn_record_inspect_common(ctx, buf, obj, GRN_FALSE);
+  return grn_record_inspect_common(ctx, buf, obj, false);
 }
 
 static grn_rc
 grn_record_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
 {
-  return grn_record_inspect_common(ctx, buf, obj, GRN_TRUE);
+  return grn_record_inspect_common(ctx, buf, obj, true);
 }
 
 static grn_rc
 grn_uvector_record_inspect_common(grn_ctx *ctx,
                                   grn_obj *buf,
                                   grn_obj *obj,
-                                  grn_bool with_columns)
+                                  bool with_columns)
 {
   unsigned int i, n = 0;
   grn_obj record;
@@ -1376,13 +1397,13 @@ grn_uvector_record_inspect_without_columns(grn_ctx *ctx,
                                            grn_obj *buf,
                                            grn_obj *obj)
 {
-  return grn_uvector_record_inspect_common(ctx, buf, obj, GRN_FALSE);
+  return grn_uvector_record_inspect_common(ctx, buf, obj, false);
 }
 
 static grn_rc
 grn_uvector_record_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
 {
-  return grn_uvector_record_inspect_common(ctx, buf, obj, GRN_TRUE);
+  return grn_uvector_record_inspect_common(ctx, buf, obj, true);
 }
 
 grn_obj *
@@ -1714,7 +1735,7 @@ grn_mkstemp(char *path_template)
 }
 #endif   /* WIN32 */
 
-grn_bool
+bool
 grn_path_exist(const char *path)
 {
   struct stat status;
